/*
 * COPYRIGHT 2020 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 * The contents of this file are proprietary and confidential.
 * Unauthorised copying of this file, via any medium is strictly prohibited.
 */

#import <Foundation/Foundation.h>

/**
 * The YOCreativeEventHandling protocol declares a set of callback methods to provide event information to a Creative or Industry Icon.\n
 * It is implemented by YOCreative and YOIndustryIcon and clients <b>must</b> call each method at the appropriate time in order for analytics
 * to be broadcast correctly.
 */
@protocol YOCreativeEventHandling <NSObject>

/** Indicates that the user clicked on the element. If a `ClickTracking` event is defined in the VAST document for the Creative
 *  then the tracking beacon will be fired.
 */
- (void) clickThroughDidOccur;

/** Indicates that a tracking event occurred for the element.
 *
 * For a list of supported events, please refer to the Creative that implements this protocol.
 *
 * @param event The tracking event name.
 * @note This handler should be raised only for events that are not directly supported through any other API.
 */
- (void) trackingEventDidOccur:(nonnull NSString*)event;

@end
