/*
 * COPYRIGHT 2020-2021 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 * The contents of this file are proprietary and confidential.
 * Unauthorised copying of this file, via any medium is strictly prohibited.
 */

#import <Foundation/Foundation.h>
#import <YOAdManagement/YOCreative.h>

/**
 * @brief Represents a linear creative object.
 *
 * Encapsulates the data from the `<Linear>` element of a VAST document and represents the actual
 * video content of an advert.\n
 * The creative may contain one or more industry icons that can be overlayed on top of the video
 * to provide some extended functionality for the advert.
 *
 * @note The class implements YOCreativeEventHandling so that it can raise `ClickTracking` and analytic
 * events on behalf of a client. It supports the following event strings:
 * - `customClick`
 * .
 */
@interface YOLinearCreative : YOCreative <YOCreativeEventHandling>

/** Contains a list of custom click URLs for the linear creative. */
@property (nullable, readonly) NSArray* customClickUrls;

@end
